@@ -1,9 +1,11 @@
-// Copyright (C) 2011-2015 Conrad Sanderson
-// Copyright (C) 2011-2015 NICTA (www.nicta.com.au)
+// Copyright (C) 2011-2015 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup arrayops
@@ -1048,202 +1050,4 @@ arrayops::has_nan(const eT* src, const uword n_elem)
 
 
 
-// TODO: this function is currently not used
-template<typename eT>
-arma_hot
-arma_pure
-inline
-typename get_pod_type<eT>::result
-arrayops::norm_1(const eT* src, const uword n_elem)
-  {
-  typedef typename get_pod_type<eT>::result T;
-  
-  T acc = T(0);
-  
-  uword i,j;
-  
-  for(i=0, j=1; j<n_elem; i+=2, j+=2)
-    {
-    acc += std::abs(src[i]);
-    acc += std::abs(src[j]);
-    }
-  
-  if(i < n_elem)
-    {
-    acc += std::abs(src[i]);
-    }
-  
-  return acc;
-  }
-
-
-
-// TODO: this function is currently not used
-template<typename eT>
-arma_hot
-arma_pure
-inline
-eT
-arrayops::norm_2(const eT* src, const uword n_elem, const typename arma_not_cx<eT>::result* junk)
-  {
-  arma_ignore(junk);
-  
-  eT acc = eT(0);
-  
-  uword i,j;
-  
-  for(i=0, j=1; j<n_elem; i+=2, j+=2)
-    {
-    const eT tmp_i = src[i];
-    const eT tmp_j = src[j];
-    
-    acc += tmp_i * tmp_i;
-    acc += tmp_j * tmp_j;
-    }
-  
-  if(i < n_elem)
-    {
-    const eT tmp_i = src[i];
-    
-    acc += tmp_i * tmp_i;
-    }
-  
-  return std::sqrt(acc);
-  }
-
-
-
-// TODO: this function is currently not used
-template<typename T>
-arma_hot
-arma_pure
-inline
-T
-arrayops::norm_2(const std::complex<T>* src, const uword n_elem)
-  {
-  T acc = T(0);
-  
-  uword i,j;
-  
-  for(i=0, j=1; j<n_elem; i+=2, j+=2)
-    {
-    const T tmp_i = std::abs(src[i]);
-    const T tmp_j = std::abs(src[j]);
-    
-    acc += tmp_i * tmp_i;
-    acc += tmp_j * tmp_j;
-    }
-  
-  if(i < n_elem)
-    {
-    const T tmp_i = std::abs(src[i]);
-    
-    acc += tmp_i * tmp_i;
-    }
-  
-  return std::sqrt(acc);
-  }
-
-
-
-// TODO: this function is currently not used
-template<typename eT>
-arma_hot
-arma_pure
-inline
-typename get_pod_type<eT>::result
-arrayops::norm_k(const eT* src, const uword n_elem, const int k)
-  {
-  typedef typename get_pod_type<eT>::result T;
-  
-  T acc = T(0);
-  
-  uword i,j;
-  
-  for(i=0, j=1; j<n_elem; i+=2, j+=2)
-    {
-    acc += std::pow(std::abs(src[i]), k);
-    acc += std::pow(std::abs(src[j]), k);
-    }
-  
-  if(i < n_elem)
-    {
-    acc += std::pow(std::abs(src[i]), k);
-    }
-  
-  return std::pow(acc, T(1)/T(k));
-  }
-
-
-
-// TODO: this function is currently not used
-template<typename eT>
-arma_hot
-arma_pure
-inline
-typename get_pod_type<eT>::result
-arrayops::norm_max(const eT* src, const uword n_elem)
-  {
-  typedef typename get_pod_type<eT>::result T;
-  
-  T max_val = std::abs(src[0]);
-  
-  uword i,j;
-  
-  for(i=1, j=2; j<n_elem; i+=2, j+=2)
-    {
-    const T tmp_i = std::abs(src[i]);
-    const T tmp_j = std::abs(src[j]);
-    
-    if(max_val < tmp_i) { max_val = tmp_i; }
-    if(max_val < tmp_j) { max_val = tmp_j; }
-    }
-  
-  if(i < n_elem)
-    {
-    const T tmp_i = std::abs(src[i]);
-    
-    if(max_val < tmp_i) { max_val = tmp_i; }
-    }
-  
-  return max_val;
-  }
-
-
-
-// TODO: this function is currently not used
-template<typename eT>
-arma_hot
-arma_pure
-inline
-typename get_pod_type<eT>::result
-arrayops::norm_min(const eT* src, const uword n_elem)
-  {
-  typedef typename get_pod_type<eT>::result T;
-  
-  T min_val = std::abs(src[0]);
-  
-  uword i,j;
-  
-  for(i=1, j=2; j<n_elem; i+=2, j+=2)
-    {
-    const T tmp_i = std::abs(src[i]);
-    const T tmp_j = std::abs(src[j]);
-    
-    if(min_val > tmp_i) { min_val = tmp_i; }
-    if(min_val > tmp_j) { min_val = tmp_j; }
-    }
-  
-  if(i < n_elem)
-    {
-    const T tmp_i = std::abs(src[i]);
-    
-    if(min_val > tmp_i) { min_val = tmp_i; }
-    }
-  
-  return min_val;
-  }
-
-
-
 //! @}
