@@ -33,10 +33,10 @@ class auxlib
   // inv
   
   template<typename eT, typename T1>
-  inline static bool inv(Mat<eT>& out, const Base<eT,T1>& X, const bool slow = false);
+  inline static bool inv(Mat<eT>& out, const Base<eT,T1>& X);
   
   template<typename eT>
-  inline static bool inv(Mat<eT>& out, const Mat<eT>& A, const bool slow = false);
+  inline static bool inv(Mat<eT>& out, const Mat<eT>& A);
   
   template<typename eT>
   inline static bool inv_noalias_tinymat(Mat<eT>& out, const Mat<eT>& X, const uword N);
@@ -70,7 +70,7 @@ class auxlib
   // det
   
   template<typename eT, typename T1>
-  inline static eT det(const Base<eT,T1>& X, const bool slow = false);
+  inline static eT det(const Base<eT,T1>& X);
   
   template<typename eT>
   inline static eT det_tinymat(const Mat<eT>& X, const uword N);
@@ -221,21 +221,26 @@ class auxlib
   //
   // solve
   
-  template<typename eT, typename T1>
-  inline static bool solve   (Mat<eT>& out, Mat<eT>& A, const Base<eT,T1>& X, const bool slow = false);
+  template<typename T1>
+  inline static bool solve_square_fast(Mat<typename T1::elem_type>& out, Mat<typename T1::elem_type>& A, const Base<typename T1::elem_type,T1>& B_expr);
   
-  template<typename eT, typename T1>
-  inline static bool solve_od(Mat<eT>& out, Mat<eT>& A, const Base<eT,T1>& X);
+  template<typename T1>
+  inline static bool solve_square_refine(Mat<typename T1::pod_type>& out, typename T1::pod_type& out_rcond, Mat<typename T1::pod_type>& A, const Base<typename T1::pod_type,T1>& B_expr, const bool equilibrate);
   
-  template<typename eT, typename T1>
-  inline static bool solve_ud(Mat<eT>& out, Mat<eT>& A, const Base<eT,T1>& X);
+  template<typename T1>
+  inline static bool solve_square_refine(Mat< std::complex<typename T1::pod_type> >& out, typename T1::pod_type& out_rcond, Mat< std::complex<typename T1::pod_type> >& A, const Base<std::complex<typename T1::pod_type>,T1>& B_expr, const bool equilibrate);
   
+  template<typename T1>
+  inline static bool solve_approx_fast(Mat<typename T1::elem_type>& out, Mat<typename T1::elem_type>& A, const Base<typename T1::elem_type,T1>& B_expr);
   
-  //
-  // solve_tr
+  template<typename T1>
+  inline static bool solve_approx_svd(Mat<typename T1::pod_type>& out, Mat<typename T1::pod_type>& A, const Base<typename T1::pod_type,T1>& B_expr);
   
-  template<typename eT>
-  inline static bool solve_tr(Mat<eT>& out, const Mat<eT>& A, const Mat<eT>& B, const uword layout);
+  template<typename T1>
+  inline static bool solve_approx_svd(Mat< std::complex<typename T1::pod_type> >& out, Mat< std::complex<typename T1::pod_type> >& A, const Base<std::complex<typename T1::pod_type>,T1>& B_expr);
+  
+  template<typename T1>
+  inline static bool solve_tri(Mat<typename T1::elem_type>& out, const Mat<typename T1::elem_type>& A, const Base<typename T1::elem_type,T1>& B_expr, const uword layout);
   
   
   //
@@ -263,6 +268,16 @@ class auxlib
   
   template<typename T, typename T1, typename T2>
   inline static bool qz(Mat< std::complex<T> >& A, Mat< std::complex<T> >& B, Mat< std::complex<T> >& vsl, Mat< std::complex<T> >& vsr, const Base< std::complex<T>, T1 >& X_expr, const Base< std::complex<T>, T2 >& Y_expr);
+  
+  
+  // 
+  // rcond
+  
+  template<typename T1>
+  inline static typename T1::pod_type rcond(const Base<typename T1::pod_type,T1>& A_expr);
+  
+  template<typename T1>
+  inline static typename T1::pod_type rcond(const Base<std::complex<typename T1::pod_type>,T1>& A_expr);
   };
 
 
