@@ -1,10 +1,12 @@
-// Copyright (C) 2008-2014 Conrad Sanderson
-// Copyright (C) 2008-2014 NICTA (www.nicta.com.au)
-// Copyright (C) 2011 Stanislav Funiak
+// Copyright (C) 2008-2015 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Written by Stanislav Funiak
 
 
 //! \addtogroup fn_eig_sym
@@ -33,7 +35,7 @@ eig_sym
   if(status == false)
     {
     eigval.reset();
-    arma_bad("eig_sym(): failed to converge", false);
+    arma_debug_warn("eig_sym(): decomposition failed");
     }
   
   return status;
@@ -60,7 +62,7 @@ eig_sym
   if(status == false)
     {
     out.reset();
-    arma_bad("eig_sym(): failed to converge");
+    arma_bad("eig_sym(): decomposition failed");
     }
   
   return out;
@@ -88,8 +90,8 @@ eig_sym
   
   const char sig = (method != NULL) ? method[0] : char(0);
   
-  arma_debug_check( ((sig != 's') && (sig != 'd')),         "eig_sym(): unknown method specified"     );
-  arma_debug_check( void_ptr(&eigval) == void_ptr(&eigvec), "eig_sym(): eigval is an alias of eigvec" );
+  arma_debug_check( ((sig != 's') && (sig != 'd')),         "eig_sym(): unknown method specified"                             );
+  arma_debug_check( void_ptr(&eigval) == void_ptr(&eigvec), "eig_sym(): parameter 'eigval' is an alias of parameter 'eigvec'" );
   
   const Proxy<T1> P(X.get_ref());
   
@@ -108,7 +110,7 @@ eig_sym
     {
     eigval.reset();
     eigvec.reset();
-    arma_bad("eig_sym(): failed to converge", false);
+    arma_debug_warn("eig_sym(): decomposition failed");
     }
   else
     {
