@@ -1,9 +1,11 @@
-// Copyright (C) 2008-2012 Conrad Sanderson
-// Copyright (C) 2008-2012 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup op_max
@@ -11,10 +13,6 @@
 
 
 
-//! \brief
-//! For each row or for each column, find the maximum value.
-//! The result is stored in a dense matrix that has either one column or one row.
-//! The dimension, for which the maxima are found, is set via the max() function.
 template<typename T1>
 inline
 void
@@ -24,22 +22,46 @@ op_max::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_max>& in)
   
   typedef typename T1::elem_type eT;
   
-  const unwrap_check<T1> tmp(in.m, out);
-  const Mat<eT>& X     = tmp.M;
-  
   const uword dim = in.aux_uword_a;
-  arma_debug_check( (dim > 1), "max(): incorrect usage. dim must be 0 or 1");
+  arma_debug_check( (dim > 1), "max(): parameter 'dim' must be 0 or 1");
+  
+  const unwrap<T1>   U(in.m);
+  const Mat<eT>& X = U.M;
+  
+  if(&out != &X)
+    {
+    op_max::apply_noalias(out, X, dim);
+    }
+  else
+    {
+    Mat<eT> tmp;
+    
+    op_max::apply_noalias(tmp, X, dim);
+    
+    out.steal_mem(tmp);
+    }
+  }
+
+
+
+template<typename eT>
+inline
+void
+op_max::apply_noalias(Mat<eT>& out, const Mat<eT>& X, const uword dim, const typename arma_not_cx<eT>::result* junk)
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk);
   
   const uword X_n_rows = X.n_rows;
   const uword X_n_cols = X.n_cols;
   
   if(dim == 0)
     {
-    arma_extra_debug_print("op_max::apply(), dim = 0");
+    arma_extra_debug_print("op_max::apply(): dim = 0");
     
-    arma_debug_check( (X_n_rows == 0), "max(): given object has zero rows" );
-
-    out.set_size(1, X_n_cols);
+    out.set_size((X_n_rows > 0) ? 1 : 0, X_n_cols);
+    
+    if(X_n_rows == 0)  { return; }
     
     eT* out_mem = out.memptr();
     
@@ -51,11 +73,66 @@ op_max::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_max>& in)
   else
   if(dim == 1)
     {
-    arma_extra_debug_print("op_max::apply(), dim = 1");
+    arma_extra_debug_print("op_max::apply(): dim = 1");
     
-    arma_debug_check( (X_n_cols == 0), "max(): given object has zero columns" );
+    out.set_size(X_n_rows, (X_n_cols > 0) ? 1 : 0);
+    
+    if(X_n_cols == 0)  { return; }
+    
+    eT* out_mem = out.memptr();
+    
+    arrayops::copy(out_mem, X.colptr(0), X_n_rows);
+    
+    for(uword col=1; col<X_n_cols; ++col)
+      {
+      const eT* col_mem = X.colptr(col);
+      
+      for(uword row=0; row<X_n_rows; ++row)
+        {
+        const eT col_val = col_mem[row];
+        
+        if(col_val > out_mem[row])  { out_mem[row] = col_val; }
+        }
+      }
+    }
+  }
 
-    out.set_size(X_n_rows, 1);
+
+
+template<typename eT>
+inline
+void
+op_max::apply_noalias(Mat<eT>& out, const Mat<eT>& X, const uword dim, const typename arma_cx_only<eT>::result* junk)
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk);
+  
+  const uword X_n_rows = X.n_rows;
+  const uword X_n_cols = X.n_cols;
+  
+  if(dim == 0)
+    {
+    arma_extra_debug_print("op_max::apply(): dim = 0");
+    
+    out.set_size((X_n_rows > 0) ? 1 : 0, X_n_cols);
+    
+    if(X_n_rows == 0)  { return; }
+    
+    eT* out_mem = out.memptr();
+    
+    for(uword col=0; col<X_n_cols; ++col)
+      {
+      out_mem[col] = op_max::direct_max( X.colptr(col), X_n_rows );
+      }
+    }
+  else
+  if(dim == 1)
+    {
+    arma_extra_debug_print("op_max::apply(): dim = 1");
+    
+    out.set_size(X_n_rows, (X_n_cols > 0) ? 1 : 0);
+    
+    if(X_n_cols == 0)  { return; }
     
     eT* out_mem = out.memptr();
     
@@ -192,8 +269,13 @@ op_max::max(const subview<eT>& X)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (X.n_elem == 0), "max(): given object has no elements" );
-
+  if(X.n_elem == 0)
+    {
+    arma_debug_check(true, "max(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+  
   const uword X_n_rows = X.n_rows;
   const uword X_n_cols = X.n_cols;
   
@@ -207,7 +289,7 @@ op_max::max(const subview<eT>& X)
     const uword start_col = X.aux_col1;
     
     const uword end_col_p1 = start_col + X_n_cols;
-  
+    
     uword i,j;
     for(i=start_col, j=start_col+1; j < end_col_p1; i+=2, j+=2)
       {
@@ -229,9 +311,7 @@ op_max::max(const subview<eT>& X)
     {
     for(uword col=0; col < X_n_cols; ++col)
       {
-      eT tmp_val = op_max::direct_max(X.colptr(col), X_n_rows);
-      
-      if(tmp_val > max_val) { max_val = tmp_val; }
+      max_val = (std::max)(max_val, op_max::direct_max(X.colptr(col), X_n_rows));
       }
     }
   
@@ -253,7 +333,12 @@ op_max::max(const Base<typename T1::elem_type,T1>& X)
   
   const uword n_elem = P.get_n_elem();
   
-  arma_debug_check( (n_elem == 0), "max(): given object has no elements" );
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "max(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
   
   eT max_val = priv::most_neg<eT>();
   
@@ -345,7 +430,12 @@ op_max::max_with_index(const Proxy<T1>& P, uword& index_of_max_val)
   
   const uword n_elem = P.get_n_elem();
   
-  arma_debug_check( (n_elem == 0), "max(): given object has no elements" );
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "max(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
   
   eT    best_val   = priv::most_neg<eT>();
   uword best_index = 0;
@@ -499,9 +589,16 @@ op_max::max(const subview< std::complex<T> >& X)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (X.n_elem == 0), "max(): given object has no elements" );
+  typedef typename std::complex<T> eT;
   
-  const Mat< std::complex<T> >& A = X.m;
+  if(X.n_elem == 0)
+    {
+    arma_debug_check(true, "max(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+  
+  const Mat<eT>& A = X.m;
   
   const uword X_n_rows = X.n_rows;
   const uword X_n_cols = X.n_cols;
@@ -569,7 +666,12 @@ op_max::max(const Base<typename T1::elem_type,T1>& X)
   
   const uword n_elem = P.get_n_elem();
   
-  arma_debug_check( (n_elem == 0), "max(): given object has no elements" );
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "max(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
   
   T max_val = priv::most_neg<T>();
   
@@ -650,7 +752,12 @@ op_max::max_with_index(const Proxy<T1>& P, uword& index_of_max_val)
   
   const uword n_elem = P.get_n_elem();
   
-  arma_debug_check( (n_elem == 0), "max(): given object has no elements" );
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "max(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
   
   T best_val = priv::most_neg<T>();
   
