@@ -1,9 +1,11 @@
-// Copyright (C) 2008-2012 Conrad Sanderson
-// Copyright (C) 2008-2012 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup subview_field
@@ -23,15 +25,18 @@ class subview_field
   
   const uword aux_row1;
   const uword aux_col1;
+  const uword aux_slice1;
   
   const uword n_rows;
   const uword n_cols;
+  const uword n_slices;
   const uword n_elem;
   
   
   protected:
   
   arma_inline subview_field(const field<oT>& in_f, const uword in_row1, const uword in_col1, const uword in_n_rows, const uword in_n_cols);
+  arma_inline subview_field(const field<oT>& in_f, const uword in_row1, const uword in_col1, const uword in_slice1, const uword in_n_rows, const uword in_n_cols, const uword in_n_slices);
   
   
   public:
@@ -49,15 +54,24 @@ class subview_field
   
   arma_inline       oT&         at(const uword row, const uword col);
   arma_inline const oT&         at(const uword row, const uword col) const;
+
+  arma_inline       oT&         at(const uword row, const uword col, const uword slice);
+  arma_inline const oT&         at(const uword row, const uword col, const uword slice) const;
   
   arma_inline       oT& operator()(const uword row, const uword col);
   arma_inline const oT& operator()(const uword row, const uword col) const;
   
+  arma_inline       oT& operator()(const uword row, const uword col, const uword slice);
+  arma_inline const oT& operator()(const uword row, const uword col, const uword slice) const;
+  
   inline bool check_overlap(const subview_field& x) const;
   
   inline void print(const std::string extra_text = "") const;
   inline void print(std::ostream& user_stream, const std::string extra_text = "") const;
   
+  template<typename functor> inline void for_each(functor F);
+  
+  inline void fill(const oT& x);
   
   inline static void extract(field<oT>& out, const subview_field& in);
   
